<?php
if ( ! function_exists( 'biography_home_fs_array' ) ) :
    /**
     * Featured Slider array creation
     *
     * @since Bizlight 1.0.0
     *
     * @param string $from_fs
     * @return array
     */
    function biography_home_fs_array( $from_fs ){
        global $biography_customizer_all_values;
        $biography_home_fs_number = absint($biography_customizer_all_values['biography-home-fs-number']);

        $biography_home_fs_contents_array = array();

        $biography_home_fs_contents_array[0]['biography-home-fs-title'] = esc_html__( 'Administrative Manager', 'biography-pro' );
        $biography_home_fs_contents_array[1]['biography-home-fs-title'] = esc_html__( 'Professional Developer', 'biography-pro' );
        $biography_home_fs_contents_array[2]['biography-home-fs-title'] = esc_html__( 'Customer Support', 'biography-pro' );

        $biography_home_fs_args = array();
        if ( 'from-category' ==  $from_fs ){
            $biography_home_fs_category = $biography_customizer_all_values['biography-home-fs-category'];
            if( 0 != $biography_home_fs_category ){
                $biography_home_fs_cat_all = $biography_customizer_all_values['biography-home-fs-cat-all'];
                if( 1 == $biography_home_fs_cat_all ){
                    $biography_home_fs_number = -1;
                }
                $biography_home_fs_args =    array(
                    'post_type' => 'post',
                    'cat' => $biography_home_fs_category,
                    'posts_per_page' => $biography_home_fs_number
                );
            }
        }
        else{
            $biography_repeated_array = array('biography-home-fs-pages-ids' );
            $biography_home_fs_posts = biography_get_repeated_all_value( 3, $biography_repeated_array );
            $biography_home_fs_posts_ids = array();
            if( null != $biography_home_fs_posts ) {
                foreach( $biography_home_fs_posts as $biography_home_fs_post ) {
                    if( 0 != $biography_home_fs_post['biography-home-fs-pages-ids'] ){
                        $biography_home_fs_posts_ids[] = $biography_home_fs_post['biography-home-fs-pages-ids'];
                    }
                }
                if( !empty( $biography_home_fs_posts_ids )){
                    $biography_home_fs_args =    array(
                        'post_type' => 'page',
                        'post__in' => $biography_home_fs_posts_ids,
                        'posts_per_page' => $biography_home_fs_number,
                        'orderby' => 'post__in'
                    );
                }
            }
        }
        // the query
        if( !empty( $biography_home_fs_args )){
            $biography_home_fs_contents_array = array(); /*again empty array*/
            $biography_home_fs_post_query = new WP_Query( $biography_home_fs_args );
            if ( $biography_home_fs_post_query->have_posts() ) :
                $i = 0;
                while ( $biography_home_fs_post_query->have_posts() ) : $biography_home_fs_post_query->the_post();
                    $biography_home_fs_contents_array[$i]['biography-home-fs-title'] = get_the_title();
                    $i++;
                endwhile;
                wp_reset_postdata();
            endif;
        }
        return $biography_home_fs_contents_array;
    }
endif;

if ( ! function_exists( 'biography_home_fs' ) ) :
    /**
     * Featured Slider
     *
     * @since Bizlight 1.0.0
     *
     * @param null
     * @return null
     *
     */
    function biography_home_fs() {
        global $biography_customizer_all_values;
        if( 1 != $biography_customizer_all_values['biography-home-fs-enable'] ){
            return null;
        }
        $biography_home_fs_selection_options = $biography_customizer_all_values['biography-home-fs-selection'];
        $biography_fs_arrays = biography_home_fs_array( $biography_home_fs_selection_options );
        if( is_array( $biography_fs_arrays )){
            ?>
            <!--text slider start-->
            <div class="slider-section">
                <div id="banner-slider" class="carousel slide" data-ride="carousel">
                    <!-- Wrapper for slides -->
                    <div class="carousel-inner" role="listbox">
                        <?php
                        $i = 1;
                        foreach( $biography_fs_arrays as $biography_slider_array ){
                            $active = '';
                            if( $i == 1 ){
                                $active = 'active';
                            }
                            ?>
                            <div class="item <?php echo esc_attr( $active ); ?>">
                                <div class="banner-slider-content">
                                    <?php echo esc_html( $biography_slider_array['biography-home-fs-title'] )?>
                                </div>
                            </div>
                            <?php
                            $i++;
                        }
                        ?>
                    </div>
                </div>
            </div><!-- .slider-section -->
            <?php
        }
        ?>
        <?php
    }
endif;
add_action( 'biography_action_text_slider', 'biography_home_fs', 20 );

if ( ! function_exists( 'biography_after_text_slider' ) ) :
    /**
     * Add button after slider
     *
     * @since Biography 1.0.0
     *
     * @param null
     * @return null
     *
     */
    function biography_after_text_slider() {
        global $biography_customizer_all_values;
        $biography_header_contact_url = $biography_customizer_all_values['biography-header-contact-url'];
        $biography_header_contact_url_button_text = $biography_customizer_all_values['biography-header-contact-url-button-text'];
        $biography_header_resume_url = $biography_customizer_all_values['biography-header-resume-url'];
        $biography_header_resume_url_button_text = $biography_customizer_all_values['biography-header-resume-url-button-text'];
        if( empty( $biography_header_contact_url) && empty ( $biography_header_resume_url ) ){
            return;
        }
        ?>
        <div class="goest-btn">
            <?php
            if( !empty( $biography_header_contact_url) ){
                ?>
                <a class="button button-feature button-contact" href="<?php echo esc_url( $biography_header_contact_url ); ?>">
                    <?php echo esc_html($biography_header_contact_url_button_text);?>
                </a>
                <?php
            }
            if( !empty( $biography_header_resume_url) ){
                ?>
                <a class="button button-feature button-resume line-btn" href="<?php echo esc_url( $biography_header_resume_url ); ?>">
                    <?php echo esc_html($biography_header_resume_url_button_text);?>
                </a>
                <?php
            }
            ?>
        </div>
        <?php
    }
endif;
add_action( 'biography_action_text_slider', 'biography_after_text_slider', 20 );