<?php
if ( ! function_exists( 'biography_set_global' ) ) :
/**
 * Setting global values for all saved customizer values
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_set_global() {
    /*Getting saved values start*/
    $GLOBALS['biography_customizer_all_values'] = biography_get_all_options(1);
}
endif;
add_action( 'biography_action_before_head', 'biography_set_global', 0 );

if ( ! function_exists( 'biography_doctype' ) ) :
/**
 * Doctype Declaration
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_doctype() {
    ?>
    <!DOCTYPE html><html <?php language_attributes(); ?>>
<?php
}
endif;
add_action( 'biography_action_before_head', 'biography_doctype', 10 );

if ( ! function_exists( 'biography_before_wp_head' ) ) :
/**
 * Before wp head codes
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_before_wp_head() {
    ?>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php
}
endif;
add_action( 'biography_action_before_wp_head', 'biography_before_wp_head', 10 );

if( ! function_exists( 'biography_default_layout' ) ) :
    /**
     * Biography default layout function
     *
     * @since  Biography 1.0.0
     *
     * @param int
     * @return string
     */
    function biography_default_layout($post_id = 0){
        global $biography_customizer_all_values,$post;
        $biography_default_layout = $biography_customizer_all_values['biography-default-layout'];
        if( is_home()){
            $post_id = get_option( 'page_for_posts' );
        }
        if( null == $post_id && isset ( $post->ID ) ){
            $post_id = $post->ID;
        }
        $biography_default_layout_meta = get_post_meta( $post_id, 'biography-default-layout', true );

        if( false != $biography_default_layout_meta ) {
            $biography_default_layout = $biography_default_layout_meta;
        }
        return $biography_default_layout;
    }
endif;

if ( ! function_exists( 'biography_body_class' ) ) :
/**
 * add body class
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_body_class( $biography_body_classes ) {
    global $biography_customizer_all_values;
    $biography_body_classes[] = $biography_customizer_all_values['biography-homepage-layout'];

    if(!is_front_page() || ( is_front_page() && 1 != biography_if_all_disable())){
        $biography_default_layout = biography_default_layout();
        if( ! is_active_sidebar( 'sidebar-1') ) {
            $biography_body_classes[] = 'biography-no-sidebar';
        }
        elseif( !empty( $biography_default_layout ) ){
            if( 'left-sidebar' == $biography_default_layout ){
                $biography_body_classes[] = 'biography-left-sidebar';
            }
            elseif( 'right-sidebar' == $biography_default_layout ){
                $biography_body_classes[] = 'biography-right-sidebar';
            }
            elseif( 'no-sidebar' == $biography_default_layout ){
                $biography_body_classes[] = 'biography-no-sidebar';
            }
            else{
                $biography_body_classes[] = 'biography-right-sidebar';
            }
        }
        else{
            $biography_body_classes[] = 'biography-right-sidebar';
        }
    }
    return $biography_body_classes;

}
endif;
add_action( 'body_class', 'biography_body_class', 10, 1);

if ( ! function_exists( 'biography_page_start' ) ) :
/**
 * page start
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_page_start() {
?>
    <div id="page" class="hfeed site">
<?php
}
endif;
add_action( 'biography_action_before', 'biography_page_start', 15 );

if ( ! function_exists( 'biography_skip_to_content' ) ) :
/**
 * Skip to content
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_skip_to_content() {
    ?>
    <a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'biography-pro' ); ?></a>
   	<?php
}
endif;
add_action( 'biography_action_before_header', 'biography_skip_to_content', 10 );

if ( ! function_exists( 'biography_header' ) ) :
/**
 * Main header
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
function biography_header() {
    global $biography_customizer_all_values;

    if ( function_exists( 'has_custom_logo' ) ) {
        $biography_logo = get_custom_logo(); 
    }
     elseif ( !function_exists( 'has_custom_logo' ) ) {
    $biography_logo = esc_url($biography_customizer_all_values['biography-logo']);
    }
    $biography_header_bg_img = biography_banner_image( get_the_ID() );
    $biography_enable_social_icons = esc_attr( $biography_customizer_all_values['biography-enable-social-icons'] );
    $nav_col_fixed = 'col-md-12 col-sm-12';

    if( 1 == $biography_enable_social_icons ){
        if( has_nav_menu( 'social' ) ) {
           $nav_col_fixed = 'col-md-6 col-sm-8';
        }
    }
    if(is_front_page() ){
    ?>

    <header id="masthead" class="site-header block-section biography-nav-left" role="banner" style="background-image: url('<?php echo  $biography_header_bg_img;?>');">
		<div class="block-overlay-content">
		<div class="head-top">
			<div class="container">
				<div class="<?php echo esc_attr( $nav_col_fixed);?> col-xs-12">
					<nav id="site-navigation" class="main-navigation" role="navigation">
						<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
						<i class="fa fa-bars"></i>
						</button>
						<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
					</nav><!-- #site-navigation -->
				</div>
				<?php
                if( 1 == $biography_enable_social_icons ){
                    if( has_nav_menu('social')){
                    ?>
                    <div class="col-md-6 col-sm-4 col-xs-12">
                        <div class="social-icon-only">
                        <?php
                        wp_nav_menu( array(
                            'theme_location'  => 'social',
                            'container'       => 'div',
                            'container_class' => 'biography-social-section',
                            'depth' => 1
                        ) );
                        ?>
                        </div>
                     </div>
                        <?php
                    }
                }
                ?>
			</div>
		</div>
        <?php
          global $biography_customizer_all_values;


          if( !FALSE == $biography_customizer_all_values['biography-home-sortable-enable']  ){

        ?>
        
            <div class="banner-section-sortable">
        <?php 
            }
            else {
        ?>
		<div class="banner-section">
        <?php } ?>
			<div class="container">
				<div class="row">
					<div class="col-md-12 col-lg-10 col-lg-offset-1">
                        <div class="banner-inner biography-animate fadeInDown overhidden">
        					<div class="author-content">
        						<div class="site-branding">
        							<?php if ( is_front_page() && is_home() ) : ?>
        								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
        							<?php else : ?>
        								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
        							<?php endif; ?>
        							<p class="site-description"><?php bloginfo( 'description' ); ?></p>
        						</div><!-- .site-branding -->
        						<?php
        						/**
                                 * biography_action_text_slider hook
                                 * @since Biography 1.0.0
                                 *
                                 * @hooked biography_text_slider -10
                                 * @hooked biography_after_text_slider -20
                                 */
                                do_action( 'biography_action_text_slider' );
        						?>
        					</div><!-- .author-content -->
                            <?php
                            if( !empty( $biography_logo)){
                            ?>
                            <div class="photo-section">
                                <span>
                                    <?php  if ( !function_exists( 'has_custom_logo' ) ) { ?>
                            <img src="<?php echo $biography_logo;?>" alt="<?php esc_attr( get_bloginfo( 'name' ) ); ?>">
                                <?php } else { ?>
                                  <?php echo $biography_logo;?>
                                <?php } ?> 
                                </span>
                            </div><!-- .photo-section -->
                            <?php
                            }
                            ?>
    					</div>
                    </div>
				</div>
			</div>
		</div>
		</div>
	</header><!-- #masthead -->
    <?php }else{?>

     <header id="masthead" class="child-site-header biography-nav-right navbar-static-top" role="banner">
        <div class="container">
                <div class="row">

                    <div class=" col-lg-2 col-xs-12 col-sm-12 col-md-2 text-center">
                        <?php
                                if( !empty( $biography_logo)){ ?>
                                <div class= "photo-section-child">
                                <span>
                                <?php 
                                if ( !function_exists( 'has_custom_logo' ) ) { ?>
                                <a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo $biography_logo;?>" alt="<?php esc_attr( get_bloginfo( 'name' ) ); ?>"></a>
                                 <?php } else { 
                                     echo $biography_logo;
                                     }
                                ?>
                                     </span>
                                 </div>
                                 
                                 
                        <?php
                                }else{ 
                        ?> 
                             <p class="child-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"> <?php bloginfo( 'name' ); ?></a> </p>
                             <p class="child-site-description"><?php bloginfo( 'description' ); ?></p>
                        <?php } ?>
                                
                    </div>

                    <div class="col-xs-12 col-sm-12 col-md-7 col-lg-7 text-center ">   
   
                       <div class="child-margin">
                                    <nav id="site-navigation" class="main-navigation child-navigation" role="navigation">
                                             <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                                                        <i class="fa fa-bars"></i>
                                              </button>
                                              <?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
                                    </nav><!-- #site-navigation -->
                        </div>
                   
                    </div>
                    <?php
                            if( 1 == $biography_enable_social_icons ){
                            if( has_nav_menu('social')){
                    ?>
                    <div class="col-md-3 col-lg-3 col-sm-12 col-xs-12 text-center">
                        <div class="social-icon-only social">
                                <?php
                                wp_nav_menu( array(
                                    'theme_location'  => 'social',
                                    'container'       => 'div',
                                    'container_class' => 'biography-social-section',
                                    'depth' => 1
                                ) );
                                ?>
                        </div>
                     </div>
                        <?php
                    }
                }
                ?>
            </div>
    </header>
    <div class="clearfix"></div>
    <section id="biography_child_page" class="biography_child_page" style="background-image:url('<?php echo $biography_header_bg_img;?>');">
    <h1 class="child-title"><?php wp_title($sep = '');?></h1>
    </section>  
<?php
}

}
endif;
add_action( 'biography_action_header', 'biography_header', 10 );

if( ! function_exists( 'biography_add_breadcrumb' ) ) :

/**
 * Breadcrumb
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return null
 *
 */
    function biography_add_breadcrumb(){
      global $biography_customizer_all_values;
      $biography_enable_breadcrumb = $biography_customizer_all_values['biography-enable-breadcrumb'];
        // Bail if Home Page
        if ( is_front_page() || is_home() || 1 != $biography_enable_breadcrumb ) {
            return;
        }
        echo '<div id="breadcrumb"><div class="container">';
         biography_simple_breadcrumb();
        echo '</div><!-- .container --></div><!-- #breadcrumb -->';
    }
endif;
add_action( 'biography_action_after_header', 'biography_add_breadcrumb', 10 );

if( ! function_exists( 'biography_content_start' ) ) :

/**
 * Content Start
 *
 * @since Biography 1.0.0
 *
 * @param null
 * @return void
 *
 */
    function biography_content_start(){
        if ( !is_front_page() || ( is_front_page() && 'posts' == get_option( 'show_on_front' ) ) ) {
            echo '<div id="content" class="site-content">';
        }
    }

endif;
add_action( 'biography_action_before_content', 'biography_content_start', 10 );
